@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: __init__.py 11438 2019-04-10 18:16:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
-# $Revision: 11436 $
+# $Date: 2019-04-11 03:16:42 +0900 (週四, 11 四月 2019) $
+# $Revision: 11438 $
 
 import os
 import logging
@@ -93,7 +93,10 @@ def open3(name, mode='r'):
     if six.PY2:
         return open(name, mode)
     else:
-        return open(name, mode, encoding='utf8')
+        if "b" in mode:
+            return open(name, mode)
+        else:
+            return open(name, mode, encoding='utf8')
 
 CSS_PROPERTIES = [
     #CSS3: https://www.w3schools.com/cssref/default.asp
